@@ -19,6 +19,9 @@
 #include <qwidget.h>
 #include <qstringlist.h>
 #include <qevent.h>
+//Added by qt3to4:
+#include <QShowEvent>
+#include <QLabel>
 
 /* OTHER INCLUDES */
 #include <kommanderwidget.h>
@@ -26,8 +29,9 @@
 #include "label.h"
 
 Label::Label(QWidget *a_parent, const char *a_name)
-  : QLabel(a_parent, a_name), KommanderWidget(this)
+  : QLabel(a_parent), KommanderWidget(this)
 {
+  setObjectName(a_name);
   QStringList states;
   states << "default";
   setStates(states);
@@ -88,24 +92,24 @@ void Label::showEvent(QShowEvent *e)
 
 bool Label::isFunctionSupported(int f)
 {
-  return f == DCOP::text || f == DCOP::setText || f == DCOP::clear;
+  return f == DBUS::text || f == DBUS::setText || f == DBUS::clear;
 }
 
-QString Label::handleDCOP(int function, const QStringList& args)
+QString Label::handleDBUS(int function, const QStringList& args)
 {
   switch (function) {
-    case DCOP::text:
+    case DBUS::text:
       return text();
-    case DCOP::setText:
+    case DBUS::setText:
       setWidgetText(args[0]);
       break;
-    case DCOP::clear:
+    case DBUS::clear:
       setWidgetText("");
       break;
     default:
-      return KommanderWidget::handleDCOP(function, args);
+      return KommanderWidget::handleDBUS(function, args);
   }
-  return QString::null;  
+  return QString();  
 }
 
 #include "label.moc"
